class EventsController < ApplicationController
  before_action :set_event, only: [:show, :edit, :update, :destroy, :invite]

  # GET /events
  # GET /events.json
  def index
    @events = paginate(Event.all, params[:page])
  end

  def past
    @events = paginate(@current_user.events.where('deadline < ?', Date.today), params[:page])
    render action: :index
  end

  def forthcoming
    @events = paginate(@current_user.events.where('deadline >= ?', Date.today), params[:page])
    render action: :index
  end

  def my
    @events = paginate(@current_user.owned_events, params[:page])
    render action: :index
  end

  # GET /events/1
  # GET /events/1.json
  def show
  end

  # GET /events/new
  def new
    @event = Event.new
  end

  # GET /events/1/edit
  def edit
  end

  # POST /events
  # POST /events.json
  def create
    @event = Event.new(event_params)
    @event.owner = @current_user

    respond_to do |format|
      if @event.save
        format.html { redirect_to @event, notice: 'Event was successfully created.' }
        format.json { render :show, status: :created, location: @event }
      else
        format.html { render :new }
        format.json { render json: @event.errors, status: :unprocessable_entity }
      end
    end
  end

  # PATCH/PUT /events/1
  # PATCH/PUT /events/1.json
  def update
    respond_to do |format|
      if @event.update(event_params)
        format.html { redirect_to @event, notice: 'Event was successfully updated.' }
        format.json { render :show, status: :ok, location: @event }
      else
        format.html { render :edit }
        format.json { render json: @event.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /events/1
  # DELETE /events/1.json
  def destroy
    @event.destroy
    respond_to do |format|
      format.html { redirect_to events_url, notice: 'Event was successfully destroyed.' }
      format.json { head :no_content }
    end
  end

  def invite
    u = User.find params[:user]
    @event.users << u unless @event.users.include? u
    render action: :show
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_event
      @event = Event.find(params[:id])
    end

    def paginate(events, page)
      events.paginate(page: page, per_page: 10)
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def event_params
      params.require(:event).permit(:user_id, :title, :description, :deadline, :priority)
    end
end
